@@ -1,10 +1,7 @@
 from __future__ import print_function
 
-# Relative import shortcut
-from core import Hub
-
 __title__ = "chanjo"
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 __author__ = "Robin Andeer"
 __license__ = "MIT"
 __copyright__ = "Copyright 2013 Robin Andeer"
